Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(160)

Unified Diff: src/date-delay.js

Issue 100335: Fix http://code.google.com/p/chromium/issues/detail?id=1717... (Closed) Base URL: http://v8.googlecode.com/svn/branches/bleeding_edge/
Patch Set: Created 11 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/date-delay.js
===================================================================
--- src/date-delay.js (revision 1832)
+++ src/date-delay.js (working copy)
@@ -1017,9 +1017,10 @@
// Setup non-enumerable constructor property of the Date prototype object.
%SetProperty($Date.prototype, "constructor", $Date, DONT_ENUM);
- // Setup non-enumerable functions of the Date prototype object and
- // set their names.
- InstallFunctions($Date.prototype, DONT_ENUM, $Array(
+ // Setup non-enumerable functions of the Date prototype object and set their
+ // names. Use DONT_DELETE due to
+ // http://code.google.com/p/chromium/issues/detail?id=1717
+ InstallFunctions($Date.prototype, DONT_ENUM | DONT_DELETE, $Array(
"toString", DateToString,
"toDateString", DateToDateString,
"toTimeString", DateToTimeString,
« no previous file with comments | « src/array.js ('k') | src/math.js » ('j') | test/mjsunit/undeletable-functions.js » ('J')

Powered by Google App Engine
This is Rietveld 408576698